# Sample Project

A complete walkthrough of the calibration and post-processing workflow is shown below. To determine how `caliscope` runs on your hardware, you can download the sample dataset used in this video [here](https://1drv.ms/f/c/a30b139c66ff49c7/EqIVjIRLQ9hEh7hLE7UysAcBvxa1Oqy8JlM8Cu1gg0mXKw?e=3PAYXa).

Please note that this demo project is meant to illustrate the workflow as simply as possible.There are a variety of improvements that could be made to improve the final results, including:

- more cameras
- higher resolution and frame rate
- better lighting
- larger calibration board
- hardware synchronization rather than folding together frames based on timestamps

<iframe width="560" height = "315" src="https://www.youtube.com/embed/voE3IKYtuIQ?si=U-ivFqX0trbjG5QA" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen></iframe>
